@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2011-2020 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2011-2022 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -32,6 +32,9 @@ $Data{'langvar'}{'iana'}{'orig'}{'name'} = {
    "Portuguese Language Orthographic Agreement of 1990 (Acordo Ortografico da Lingua Portuguesa de 1990)",
    "Niçard"                           => "Nicard",
    "Provençal"                       => "Provencal",
+   "Østgrønlands"                 =>"Ostgronlands",
+   "Latvian orthography used before 1920s (\"vecā druka\")" =>
+   "Latvian orthography used before 1920s (\"veca druka\")",
 };
 
 $Data{'langvar'}{'iana'}{'ignore'} = {
